@@ -16,16 +16,19 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
-from . variable import Variable
-from ... constraints.semi_definite import SDP
+from cvxpy.expressions.variables.variable import Variable
+from cvxpy.constraints.semi_definite import SDP
+import cvxpy.lin_ops.lin_utils as lu
 
 class semidefinite(Variable):
     """ A semidefinite variable. """
     def __init__(self, n, name=None):
         super(semidefinite, self).__init__(n,n,name)
 
-    # A semidefinite variable is no different from a normal variable except
-    # that it adds an SDP constraint on the variable.
     def canonicalize(self):
+        """Variable must be semidefinite and symmetric.
+        """
         obj, constr = super(semidefinite, self).canonicalize()
-        return (obj, constr + [SDP(obj)])
+        obj_transpose = lu.transpose(obj)
+        return (obj, constr + [lu.create_eq(obj, obj_transpose),
+                               SDP(obj)])
